# Core Module

The `wandas.core` module provides the foundation components of the Wandas library.

## BaseFrame

BaseFrame is the base class for all Wandas frames. It defines the basic data structure and operations.

::: wandas.core.base_frame.BaseFrame

## ChannelMetadata

The ChannelMetadata class manages metadata related to audio channels.

::: wandas.core.metadata.ChannelMetadata
